| Copyright | (c) 2020-2021 berberman |
|---|---|
| License | MIT |
| Maintainer | berberman <berberman@yandex.com> |
| Stability | experimental |
| Portability | portable |
| Safe Haskell | None |
| Language | Haskell2010 |
Distribution.ArchHs.FilesDB
Description
This module provides functions operating with FilesDB of pacman.
Documentation
defaultFilesDBDir :: FilePath Source #
Default directory containing files dbs (varlibpacmansync).
lookupPkg :: File -> FilesDB -> [ArchLinuxName] Source #
Lookup which Arch Linux package contains this file from given files db.
This query is bad in performance, since it traverses the entire db.
Three files repos: core, community, and extra