| Copyright | (c) 2020-2021 berberman |
|---|---|
| License | MIT |
| Maintainer | berberman <berberman@yandex.com> |
| Stability | experimental |
| Portability | portable |
| Safe Haskell | None |
| Language | Haskell2010 |
Distribution.ArchHs.PkgBuild
Description
Template of PKGBUILD file.
Documentation
PkgBuild data type, representing needed information in filling the felixTemplate.
Constructors
| PkgBuild | |
Fields
| |
mapLicense :: LicenseId -> License Source #
Map LicenseId to ArchLicense. License not provided by system will be mapped to custom:....
showArchLicense :: License -> String Source #
Show an archlinux license
applyTemplate :: PkgBuild -> String Source #
Apply PkgBuild to felixTemplate.